@@ -38,12 +38,11 @@
  */
 #define GWEN_BUFFER_DYNAMIC_STEP 1024
 
-#define GWEN_BUFFER_FLAGS_OWNED   0x0001
-#define GWEN_BUFFER_FLAGS_OWN_BIO 0x0002
-#define GWEN_BUFFER_FLAGS_OWN_IO  0x0004
+#define GWEN_BUFFER_FLAGS_OWNED      0x0001
+#define GWEN_BUFFER_FLAGS_OWN_SYNCIO 0x0002
 
 #define GWEN_BUFFER_MODE_COPYMASK (\
-  ~(GWEN_BUFFER_MODE_USE_BIO) \
+  ~(GWEN_BUFFER_FLAGS_OWN_SYNCIO) \
   )
 
 
@@ -59,8 +58,7 @@ struct GWEN_BUFFER {
   uint32_t hardLimit;
   uint32_t step;
   uint32_t bookmarks[GWEN_BUFFER_MAX_BOOKMARKS];
-  GWEN_BUFFEREDIO *bio;
-  GWEN_IO_LAYER *ioLayer;
+  GWEN_SYNCIO *syncIo;
 };
 
 
@@ -71,8 +69,7 @@ static void GWEN_Buffer_AdjustBookmarks(GWEN_BUFFER *bf,
 
 
 static int GWEN_Buffer__FillBuffer(GWEN_BUFFER *bf);
-static int GWEN_Buffer__FillBuffer_Bio(GWEN_BUFFER *bf);
-static int GWEN_Buffer__FillBuffer_IoLayer(GWEN_BUFFER *bf);
+static int GWEN_Buffer__FillBuffer_SyncIo(GWEN_BUFFER *bf);
 
 
 #endif
