@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: gwenhywfarapi.h 1393 2007-11-22 18:26:05Z martin $
+    cvs         : $Id$
     begin       : Wed Sep 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -34,6 +34,7 @@
 # define GWENHYWFAR_API
 # define GWENHYWFAR_EXPORT
 # define GWENHYWFAR_NOEXPORT
+# define GWEN_UNUSED
 #else
 # ifdef BUILDING_GWENHYWFAR
    /* building Gwenhywfar */
@@ -75,6 +76,11 @@
 #  define GWENHYWFAR_NOEXPORT
 # endif
 
+# ifdef __GNUC__
+#  define GWEN_UNUSED __attribute__((unused))
+# else
+#  define GWEN_UNUSED
+# endif
 #endif
 
 #if GWENHYWFAR_SYS_IS_WINDOWS
@@ -131,8 +137,12 @@
 #if __GNUC_PREREQ(3, 0)
 /* Only available in gcc >= 3.0.x */
 # define DEPRECATED __attribute__((deprecated))
+# define GWEN_LIKELY(cond) __builtin_expect(!!(cond), 1)
+# define GWEN_UNLIKELY(cond) __builtin_expect(!!(cond), 0)
 #else
 # define DEPRECATED
+# define GWEN_LIKELY(cond) (!!(cond))
+# define GWEN_UNLIKELY(cond) (!!(cond))
 #endif /* __GNUC__ */
 
 
