@@ -47,7 +47,7 @@ GWEN_LIST_FUNCTIONS(GWEN_TIME_TMPLCHAR, GWEN_TimeTmplChar)
 
 
 
-GWEN_TIME *GWEN_CurrentTime(){
+GWEN_TIME *GWEN_CurrentTime(void){
   GWEN_TIME *t;
 
   GWEN_NEW_OBJECT(GWEN_TIME, t);
