@@ -1637,7 +1637,7 @@ int GWEN_XMLNode_StripNamespaces(GWEN_XMLNODE *n) {
 
 
 
-GWEN_XMLNODE_PATH *GWEN_XMLNode_Path_new(){
+GWEN_XMLNODE_PATH *GWEN_XMLNode_Path_new(void){
   GWEN_XMLNODE_PATH *p;
 
   GWEN_NEW_OBJECT(GWEN_XMLNODE_PATH, p);
