@@ -750,7 +750,7 @@ typedef struct GWEN_XMLNODE_PATH GWEN_XMLNODE_PATH;
 
 
 GWENHYWFAR_API
-GWEN_XMLNODE_PATH *GWEN_XMLNode_Path_new();
+GWEN_XMLNODE_PATH *GWEN_XMLNode_Path_new(void);
 GWENHYWFAR_API
 GWEN_XMLNODE_PATH *GWEN_XMLNode_Path_dup(const GWEN_XMLNODE_PATH *np);
 GWENHYWFAR_API
