@@ -49,17 +49,14 @@ GWEN_INHERIT_FUNCTIONS(GWEN_XML_CONTEXT)
 
 
 
-GWEN_XML_CONTEXT *GWEN_XmlCtx_new(uint32_t flags,
-				  uint32_t guiid,
-				  int timeout) {
+GWEN_XML_CONTEXT *GWEN_XmlCtx_new(uint32_t flags) {
   GWEN_XML_CONTEXT *ctx;
 
   GWEN_NEW_OBJECT(GWEN_XML_CONTEXT, ctx);
+  ctx->_refCount=1;
   GWEN_INHERIT_INIT(GWEN_XML_CONTEXT, ctx);
 
   ctx->flags=flags;
-  ctx->guiid=guiid;
-  ctx->timeout=timeout;
 
   return ctx;
 }
@@ -68,23 +65,23 @@ GWEN_XML_CONTEXT *GWEN_XmlCtx_new(uint32_t flags,
 
 void GWEN_XmlCtx_free(GWEN_XML_CONTEXT *ctx) {
   if (ctx) {
-    GWEN_INHERIT_FINI(GWEN_XML_CONTEXT, ctx);
-    GWEN_FREE_OBJECT(ctx);
+    assert(ctx->_refCount);
+    if (ctx->_refCount==1) {
+      GWEN_INHERIT_FINI(GWEN_XML_CONTEXT, ctx);
+      ctx->_refCount=0;
+      GWEN_FREE_OBJECT(ctx);
+    }
+    else
+      ctx->_refCount--;
   }
 }
 
 
 
-uint32_t GWEN_XmlCtx_GetGuiId(const GWEN_XML_CONTEXT *ctx) {
+void GWEN_XmlCtx_Attach(GWEN_XML_CONTEXT *ctx) {
   assert(ctx);
-  return ctx->guiid;
-}
-
-
-
-int GWEN_XmlCtx_GetTimeout(const GWEN_XML_CONTEXT *ctx) {
-  assert(ctx);
-  return ctx->timeout;
+  assert(ctx->_refCount);
+  ctx->_refCount++;
 }
 
 
@@ -318,13 +315,10 @@ int GWEN_XmlCtx_AddAttr(GWEN_XML_CONTEXT *ctx,
 
 
 
-GWEN_XML_CONTEXT *GWEN_XmlCtxStore_new(GWEN_XMLNODE *n,
-				       uint32_t flags,
-				       uint32_t guiid,
-				       int timeout) {
+GWEN_XML_CONTEXT *GWEN_XmlCtxStore_new(GWEN_XMLNODE *n, uint32_t flags) {
   GWEN_XML_CONTEXT *ctx;
 
-  ctx=GWEN_XmlCtx_new(flags, guiid, timeout);
+  ctx=GWEN_XmlCtx_new(flags);
   assert(ctx);
 
   GWEN_XmlCtx_SetCurrentNode(ctx, n);
@@ -357,6 +351,15 @@ int GWEN_XmlCtxStore_StartTag(GWEN_XML_CONTEXT *ctx, const char *tagName) {
     GWEN_XMLNode_AddHeader(currNode, newNode);
     GWEN_XmlCtx_SetCurrentHeader(ctx, newNode);
   }
+  else if (strcasecmp(tagName, "!DOCTYPE")==0) {
+    newNode=GWEN_XMLNode_new(GWEN_XMLNodeTypeTag, tagName);
+    assert(newNode);
+    DBG_VERBOUS(GWEN_LOGDOMAIN, "Adding header [%s] to [%s]",
+                GWEN_XMLNode_GetData(newNode),
+                GWEN_XMLNode_GetData(currNode));
+    GWEN_XMLNode_AddHeader(currNode, newNode);
+    GWEN_XmlCtx_SetCurrentHeader(ctx, newNode);
+  }
   else if (*tagName=='/') {
     const char *s;
 
@@ -611,9 +614,18 @@ int GWEN_XmlCtxStore_AddAttr(GWEN_XML_CONTEXT *ctx,
     }
 
     if (isNormalProperty) {
+      GWEN_BUFFER *buf;
+
       DBG_VERBOUS(GWEN_LOGDOMAIN, "Setting attribute of tag [%s]: [%s]=[%s]",
 		  GWEN_XMLNode_GetData(currNode), attrName, attrData);
-      GWEN_XMLNode_SetProperty(currNode, attrName, attrData);
+      buf=GWEN_Buffer_new(0, 64, 0, 1);
+      if (GWEN_Text_UnescapeXmlToBuffer(attrData, buf)) {
+	GWEN_Buffer_free(buf);
+	DBG_INFO(GWEN_LOGDOMAIN, "here");
+	return GWEN_ERROR_BAD_DATA;
+      }
+      GWEN_XMLNode_SetProperty(currNode, attrName, GWEN_Buffer_GetStart(buf));
+      GWEN_Buffer_free(buf);
     }
   }
 
