@@ -1280,11 +1280,22 @@ int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf) {
   int firstRead=1;
   int bodySize=-1;
   int bytesRead=0;
+  uint32_t pid;
 
   assert(sio);
   xio=GWEN_INHERIT_GETDATA(GWEN_SYNCIO, GWEN_SYNCIO_HTTP, sio);
   assert(xio);
 
+  pid=GWEN_Gui_ProgressStart(GWEN_GUI_PROGRESS_DELAY |
+                             GWEN_GUI_PROGRESS_SHOW_ABORT |
+                             GWEN_GUI_PROGRESS_ALLOW_EMBED |
+                             GWEN_GUI_PROGRESS_SHOW_PROGRESS,
+                             I18N("Network Operation"),
+                             I18N("Receiving data"),
+                             0,
+                             0);
+
+
   /* recv packet (this reads the HTTP body) */
   for (;;) {
     uint8_t *p;
@@ -1293,6 +1304,7 @@ int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf) {
     rv=GWEN_Buffer_AllocRoom(buf, 1024);
     if (rv<0) {
       DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+      GWEN_Gui_ProgressEnd(pid);
       return rv;
     }
 
@@ -1310,6 +1322,7 @@ int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf) {
 	    DBG_ERROR(GWEN_LOGDOMAIN,
 		      "EOF met prematurely (%d < %d)",
 		      bytesRead, bodySize);
+            GWEN_Gui_ProgressEnd(pid);
 	    return GWEN_ERROR_EOF;
 	}
       }
@@ -1327,15 +1340,28 @@ int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf) {
 
 	db=GWEN_SyncIo_Http_GetDbHeaderIn(sio);
 	bodySize=GWEN_DB_GetIntValue(db, "Content-length", 0, -1);
+
+	if (bodySize!=-1)
+	  GWEN_Gui_ProgressSetTotal(pid, bodySize);
       }
       bytesRead+=rv;
+
+      /* advance progress bar */
+      rv=GWEN_Gui_ProgressAdvance(pid, bytesRead);
+      if (rv==GWEN_ERROR_USER_ABORTED) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        GWEN_Gui_ProgressEnd(pid);
+        return rv;
+      }
     }
 
     if (bodySize!=-1 && bytesRead>=bodySize) {
       break;
     }
+
     firstRead=0;
   }
+  GWEN_Gui_ProgressEnd(pid);
 
   if (rv<0) {
     if (GWEN_Buffer_GetUsedBytes(buf)) {
@@ -1390,4 +1416,147 @@ int GWEN_SyncIo_Http_RecvBody(GWEN_SYNCIO *sio, GWEN_BUFFER *buf) {
 
 
 
+int GWEN_SyncIo_Http_RecvBodyToSio(GWEN_SYNCIO *sio, GWEN_SYNCIO *sout) {
+  GWEN_SYNCIO_HTTP *xio;
+  int rv;
+  int code=0;
+  int firstRead=1;
+  int bodySize=-1;
+  int bytesRead=0;
+  uint32_t pid;
+
+  assert(sio);
+  xio=GWEN_INHERIT_GETDATA(GWEN_SYNCIO, GWEN_SYNCIO_HTTP, sio);
+  assert(xio);
+
+  pid=GWEN_Gui_ProgressStart(GWEN_GUI_PROGRESS_DELAY |
+                             GWEN_GUI_PROGRESS_SHOW_ABORT |
+                             GWEN_GUI_PROGRESS_ALLOW_EMBED |
+                             GWEN_GUI_PROGRESS_SHOW_PROGRESS,
+                             I18N("Network Operation"),
+                             I18N("Receiving data"),
+                             0,
+                             0);
+
+  /* recv packet (this reads the HTTP body) */
+  for (;;) {
+    uint8_t *p;
+    uint32_t l;
+    uint8_t rbuf[1024];
+
+    p=rbuf;
+    l=sizeof(rbuf);
+
+    do {
+      rv=GWEN_SyncIo_Read(sio, p, l-1);
+    } while(rv==GWEN_ERROR_INTERRUPTED);
+
+    if (rv==0)
+      break;
+    else if (rv<0) {
+      if (rv==GWEN_ERROR_EOF) {
+	if (bodySize!=-1 && bytesRead<bodySize) {
+	    DBG_ERROR(GWEN_LOGDOMAIN,
+		      "EOF met prematurely (%d < %d)",
+		      bytesRead, bodySize);
+            GWEN_Gui_ProgressEnd(pid);
+	    return GWEN_ERROR_EOF;
+	}
+      }
+      else {
+	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+	/*return rv;*/
+        break;
+      }
+    }
+    else {
+      int rv2;
+
+      rv2=GWEN_SyncIo_WriteForced(sout, rbuf, rv);
+      if (rv2<0) {
+	DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv2);
+        GWEN_Gui_ProgressEnd(pid);
+	return rv2;
+      }
+      if (firstRead) {
+	GWEN_DB_NODE *db;
+
+	db=GWEN_SyncIo_Http_GetDbHeaderIn(sio);
+	bodySize=GWEN_DB_GetIntValue(db, "Content-length", 0, -1);
+
+	if (bodySize!=-1)
+	  GWEN_Gui_ProgressSetTotal(pid, bodySize);
+      }
+      bytesRead+=rv;
+
+      /* advance progress bar */
+      rv=GWEN_Gui_ProgressAdvance(pid, bytesRead);
+      if (rv==GWEN_ERROR_USER_ABORTED) {
+        DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+        GWEN_Gui_ProgressEnd(pid);
+        return rv;
+      }
+    }
+
+    if (bodySize!=-1 && bytesRead>=bodySize) {
+      break;
+    }
+    firstRead=0;
+  }
+  GWEN_Gui_ProgressEnd(pid);
+
+
+  if (rv<0) {
+    if (bytesRead) {
+      /* data received, check for common error codes */
+      if (rv==GWEN_ERROR_EOF || rv==GWEN_ERROR_IO || rv==GWEN_ERROR_SSL) {
+	DBG_INFO(GWEN_LOGDOMAIN,
+		 "We received an error, but we still got data, "
+		 "so we ignore the error here");
+      }
+      else {
+	DBG_INFO(GWEN_LOGDOMAIN, "No message received (%d)", rv);
+	GWEN_Gui_ProgressLog(0,
+			     GWEN_LoggerLevel_Error,
+			     I18N("No message received"));
+	return rv;
+      }
+    }
+    else {
+      DBG_INFO(GWEN_LOGDOMAIN, "No message received (%d)", rv);
+      GWEN_Gui_ProgressLog(0,
+			   GWEN_LoggerLevel_Error,
+			   I18N("No message received"));
+      return rv;
+    }
+  }
+
+  if (GWEN_SyncIo_GetFlags(sio) & GWEN_SYNCIO_FLAGS_PASSIVE)
+    code=0;
+  else {
+    code=GWEN_DB_GetIntValue(xio->dbStatusIn, "code", 0, 0);
+    if (code) {
+      const char *s;
+
+      s=GWEN_DB_GetCharValue(xio->dbStatusIn, "text", 0, NULL);
+      DBG_DEBUG(GWEN_LOGDOMAIN, "HTTP-Status: %d (%s)",
+		code, s?s:"- no text -");
+      GWEN_Gui_ProgressLog2(0, GWEN_LoggerLevel_Info,
+			    I18N("HTTP-Status: %d (%s)"),
+			    code, s?s:I18N("- no details -)"));
+    }
+    else {
+      DBG_ERROR(GWEN_LOGDOMAIN, "No HTTP status code received");
+      GWEN_Gui_ProgressLog(0,
+			   GWEN_LoggerLevel_Error,
+			   I18N("No HTTP status code received"));
+      code=GWEN_ERROR_BAD_DATA;
+    }
+  }
+
+  return code;
+}
+
+
+
 
